@@ -25,7 +25,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 '''
 
 __version__ = "0.3"
@@ -37,7 +37,6 @@ from datetime import *
 import inkex
 import simplestyle
 
-inkex.localize()
 
 class SVGCalendar (inkex.Effect):
 
